@@ -19,6 +19,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file cdbase.c
+    \brief Dummy and ISO, BIN/CUE, MDS CD Interfaces
+*/
+
 #include <string.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -345,6 +349,7 @@ static int LoadBinCue(const char *cuefilename, FILE *iso_file)
    track_info_struct trk[100];
    int file_size;
    int i;
+   FILE * bin_file;
 
    disc.session_num = 1;
    disc.session = malloc(sizeof(session_info_struct) * disc.session_num);
@@ -437,10 +442,9 @@ static int LoadBinCue(const char *cuefilename, FILE *iso_file)
    // Go back, retrieve image filename
    fseek(iso_file, 0, SEEK_SET);
    fscanf(iso_file, "FILE \"%[^\"]\" %*s\r\n", temp_buffer);
-   fclose(iso_file);
 
    // Now go and open up the image file, figure out its size, etc.
-   if ((iso_file = fopen(temp_buffer, "rb")) == NULL)
+   if ((bin_file = fopen(temp_buffer, "rb")) == NULL)
    {
       // Ok, exact path didn't work. Let's trim the path and try opening the
       // file from the same directory as the cue.
@@ -486,10 +490,10 @@ static int LoadBinCue(const char *cuefilename, FILE *iso_file)
       strcat(temp_buffer2, p);
 
       // Let's give it another try
-      iso_file = fopen(temp_buffer2, "rb");
+      bin_file = fopen(temp_buffer2, "rb");
       free(temp_buffer2);
 
-      if (iso_file == NULL)
+      if (bin_file == NULL)
       {
          YabSetError(YAB_ERR_FILENOTFOUND, temp_buffer);
          free(temp_buffer);
@@ -497,15 +501,15 @@ static int LoadBinCue(const char *cuefilename, FILE *iso_file)
       }
    }
 
-   fseek(iso_file, 0, SEEK_END);
-   file_size = ftell(iso_file);
-   fseek(iso_file, 0, SEEK_SET);
+   fseek(bin_file, 0, SEEK_END);
+   file_size = ftell(bin_file);
+   fseek(bin_file, 0, SEEK_SET);
 
    for (i = 0; i < track_num; i++)
    {
       trk[i].fad_end = trk[i+1].fad_start-1;
       trk[i].file_id = 0;
-      trk[i].fp = iso_file;
+      trk[i].fp = bin_file;
       trk[i].file_size = file_size;
    }
 
@@ -527,6 +531,8 @@ static int LoadBinCue(const char *cuefilename, FILE *iso_file)
 
    // buffer is no longer needed
    free(temp_buffer);
+
+   fclose(iso_file);
    return 0;
 }
 
@@ -549,7 +555,7 @@ int LoadMDSTracks(const char *mds_filename, FILE *iso_file, mds_session_struct *
    {
       mds_track_struct track;
       FILE *fp=NULL;
-      int file_size;
+      int file_size = 0;
 
       fseek(iso_file, mds_session->track_blocks_offset + i * sizeof(mds_track_struct), SEEK_SET);
       if (fread(&track, 1, sizeof(mds_track_struct), iso_file) != sizeof(mds_track_struct))
