@@ -46,8 +46,8 @@ void yui_gl_draw(YuiGl * glxarea) {
 #else
 	int buf_width, buf_height;
 	GdkPixbuf * pixbuf, * scaledpixbuf;
-	
-	VIDSoftGetScreenSize( &buf_width, &buf_height );
+
+	VIDCore->GetGlSize( &buf_width, &buf_height );
 	glxarea->pixels_width = GTK_WIDGET(glxarea)->allocation.width;
 	glxarea->pixels_height = GTK_WIDGET(glxarea)->allocation.height;
 	glxarea->pixels_rowstride = glxarea->pixels_width * 4;
@@ -212,7 +212,7 @@ GtkWidget * yui_gl_new(void) {
 		GDK_GL_DOUBLEBUFFER,
 
 		GDK_GL_DEPTH_SIZE ,1,
-
+        GDK_GL_STENCIL_SIZE ,8,
 		GDK_GL_ATTRIB_LIST_NONE 
 	};
 #endif
@@ -259,11 +259,11 @@ void yui_gl_dump_screen(YuiGl * glxarea) {
 	u8 * pixels;
 	u8 * buffer;
 
-	VIDSoftGetScreenSize( &buf_width, &buf_height );
+	VIDCore->GetGlSize( &buf_width, &buf_height );
 	size = buf_width * buf_height * 3;
 
-	glxarea->pixels_width = GTK_WIDGET(glxarea)->allocation.width;
-	glxarea->pixels_height = GTK_WIDGET(glxarea)->allocation.height;
+	glxarea->pixels_width = buf_width;
+	glxarea->pixels_height = buf_height;
 	glxarea->pixels_rowstride = glxarea->pixels_width * 3;
 	glxarea->pixels_rowstride += (glxarea->pixels_rowstride % 4)? (4 - (glxarea->pixels_rowstride % 4)): 0;
 
