@@ -1,4 +1,4 @@
-/*  Copyright 2006 Guillaume Duhamel
+/*  Copyright 2006-2011 Guillaume Duhamel
     Copyright 2006 Fabien Coulon
 
     This file is part of Yabause.
@@ -29,24 +29,56 @@
 
 #include "../scsp.h"
 
-YuiRangeItem sh2interpreters[] = {
-  { "0", "Fast Interpreter" },
-  { "1", "Debug Interpreter" },
-#ifdef SH2_DYNAREC
-  { "2", "Dynamic Recompiler" },
-#endif
-#ifdef TEST_PSP_SH2
-  { "1486", "PSP Interpreter (for debugging)" },
-#endif
-  { 0, 0 }
-};
+typedef struct {
+	int id;
+	const char *Name;
+} GenericInterface_struct;
 
-YuiRangeItem m68kinterpreters[] = {
-  { "1", "Standard Interpreter" },
-  { "2", "Q68 Interpreter" },
-  { "0", "Disabled" },
-  { 0, 0 }
-};
+void cores_to_range(void * pointer, YuiRangeItem ** items) {
+	GenericInterface_struct ** cores;
+	GenericInterface_struct * core;
+	int i;
+
+	if (*items != NULL) return;
+
+	cores = pointer;
+
+	i = 0;
+	core = cores[i];
+	while(core) {
+		i++;
+		core = cores[i];
+	}
+	*items = malloc(sizeof(YuiRangeItem) * (i + 1));
+	i = 0;
+	core = cores[i];
+	while(core) {
+		char buffer[1024];
+		(*items)[i].name = strdup(core->Name);
+		sprintf(buffer, "%d", core->id);
+		(*items)[i].value = strdup(buffer);
+		i++;
+		core = cores[i];
+	}
+	(*items)[i].name = NULL;
+	(*items)[i].value = NULL;
+}
+
+extern CDInterface *SH2CoreList[];
+extern CDInterface *M68KCoreList[];
+extern CDInterface *CDCoreList[];
+extern CDInterface *VIDCoreList[];
+extern CDInterface *OSDCoreList[];
+extern CDInterface *SNDCoreList[];
+extern CDInterface *PERCoreList[];
+
+YuiRangeItem * sh2interpreters = NULL;
+YuiRangeItem * m68kinterpreters = NULL;
+YuiRangeItem * cdcores = NULL;
+YuiRangeItem * vidcores = NULL;
+YuiRangeItem * osdcores = NULL;
+YuiRangeItem * sndcores = NULL;
+YuiRangeItem * percores = NULL;
 
 YuiRangeItem regions[] = {
 	{ "Auto" , "Auto-detect" },
@@ -75,35 +107,6 @@ YuiRangeItem carttypes[] = {
 	{ 0, 0 }
 };
 
-YuiRangeItem cdcores[] = {
-	{ "0" , "Dummy CD" },
-	{ "1" , "ISO or CUE file" },
-#ifndef UNKNOWN_ARCH
-	{ "2" , "Cdrom device" },
-#endif
-	{ 0, 0 }
-};
-
-YuiRangeItem vidcores[] = {
-	{ "0", "Dummy Video Interface" },
-#ifdef HAVE_LIBGTKGLEXT
-	{ "1", "OpenGL Video Interface" },
-#endif
-	{ "2", "Software Video Interface" },
-	{ 0, 0 }
-};
-
-YuiRangeItem sndcores[] = {
-	{ "0", "Dummy Sound Interface" },
-#ifdef HAVE_LIBSDL
-	{ "1", "SDL Sound Interface" },
-#endif
-#ifdef HAVE_LIBAL
-	{ "2", "OpenAL Sound Interface" },
-#endif
-	{ 0, 0 }
-};
-
 const gchar * keys1[] = { "Up", "Right", "Down", "Left", "R", "L", 0 };
 const gchar * keys2[] = { "A", "B", "C", "X", "Y", "Z", "Start", 0 };
 
@@ -113,17 +116,6 @@ YuiRangeItem vidformats[] = {
 	{ 0, 0 }
 };
 
-YuiRangeItem percores[] = {
-	{ "2", "Gtk Input Interface" },
-#ifdef HAVE_LIBSDL
-	{ "3", "SDL Joystick Interface" },
-#endif
-#ifdef ARCH_IS_LINUX
-	{ "4", "Linux Joystick Interface" },
-#endif
-	{ 0, 0 }
-};
-
 YuiRangeItem mousepercores[] = {
 	{ "2", "Gtk Input Interface" },
 	{ 0, 0 }
@@ -284,6 +276,10 @@ static void disable_enable_fixed_base_time(YuiCheckButton *clocksync, YuiCheckBu
 	                         yui_check_button_get_active(clocksync));
 }
 
+static void volume_changed(GtkRange * range, gpointer data) {
+    g_key_file_set_integer(keyfile, "General", "Volume", (int) gtk_range_get_value(range));
+}
+
 GtkWidget* create_dialog1(void) {
   GtkWidget *dialog1;
   GtkWidget *notebook1;
@@ -295,6 +291,14 @@ GtkWidget* create_dialog1(void) {
   GtkWidget * box;
   u8 perid;
 
+  cores_to_range(SH2CoreList, &sh2interpreters);
+  cores_to_range(M68KCoreList, &m68kinterpreters);
+  cores_to_range(CDCoreList, &cdcores);
+  cores_to_range(VIDCoreList, &vidcores);
+  cores_to_range(OSDCoreList, &osdcores);
+  cores_to_range(SNDCoreList, &sndcores);
+  cores_to_range(PERCoreList, &percores);
+
   dialog1 = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (dialog1), "Yabause configuration");
   gtk_window_set_icon_name (GTK_WINDOW (dialog1), "gtk-preferences");
@@ -332,6 +336,11 @@ GtkWidget* create_dialog1(void) {
   box = yui_page_add(YUI_PAGE(video_sound), _("Video Core"));
   gtk_container_add(GTK_CONTAINER(box), yui_range_new(keyfile, "General", "VideoCore", vidcores));
 
+#ifdef YAB_PORT_OSD
+  box = yui_page_add(YUI_PAGE(video_sound), _("OSD Core"));
+  gtk_container_add(GTK_CONTAINER(box), yui_range_new(keyfile, "General", "OSDCore", osdcores));
+#endif
+
   box = yui_page_add(YUI_PAGE(video_sound), _("Resolution"));
   gtk_container_add(GTK_CONTAINER(box), yui_resolution_new(keyfile, "General"));
 
@@ -357,6 +366,17 @@ GtkWidget* create_dialog1(void) {
 
   box = yui_page_add(YUI_PAGE(sound), _("Sound Core"));
   gtk_container_add(GTK_CONTAINER(box), yui_range_new(keyfile, "General", "SoundCore", sndcores));
+
+  {
+    GtkWidget * volume;
+
+    box = yui_page_add(YUI_PAGE(sound), _("Volume"));
+    gtk_container_set_border_width(GTK_CONTAINER(box), 10);
+    volume = gtk_hscale_new_with_range(0, 100, 1);
+    gtk_range_set_value(GTK_RANGE(volume), g_key_file_get_integer(keyfile, "General", "Volume", NULL));
+    g_signal_connect(volume, "value-changed", G_CALLBACK(volume_changed), NULL);
+    gtk_container_add(GTK_CONTAINER(box), volume);
+  }
   
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook1), sound, gtk_label_new (_("Sound")));
   gtk_widget_show_all(sound);
@@ -543,3 +563,7 @@ GtkWidget* create_dialog1(void) {
 
   return dialog1;
 }
+
+void yui_texture_free(guchar *pixels, gpointer data) {
+  free(pixels);
+}
