@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with Yabause; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 #include <gtk/gtk.h>
@@ -131,7 +131,7 @@ GtkWidget * yui_scudsp_new(YuiWindow * y) {
   GtkWidget * dialog;
   GClosure *closureF7;
   GtkAccelGroup *accelGroup;
-  scucodebreakpoint_struct *cbp;
+  const scucodebreakpoint_struct *cbp;
   gint i;
   yui = y;
 
@@ -141,8 +141,8 @@ GtkWidget * yui_scudsp_new(YuiWindow * y) {
   yui_scudsp = YUI_SCUDSP(dialog);
 
   if (!( yui->state & YUI_IS_INIT )) {
-    yui_window_run(dialog, yui);
-    yui_window_pause(dialog, yui);
+    yui_window_run(yui);
+    yui_window_pause(yui);
   }
 
   ScuDspSetBreakpointCallBack(&yui_scudsp_breakpoint_handler);
@@ -240,7 +240,7 @@ static void yui_scudsp_update_reglist( YuiScudsp *scudsp, scudspregs_struct *reg
   SCUDSPUPDATEREGLIST(TOP,%02X);
   SCUDSPUPDATEREGLIST(LOP,%02X);
   gtk_tree_model_iter_next( GTK_TREE_MODEL( scudsp->regListStore ), &iter );
-  sprintf(valuestr, "%08X", ((u32)(regs->CT[0]))<<24 + ((u32)(regs->CT[1]))<<16 + ((u32)(regs->CT[2]))<<8 + ((u32)(regs->CT[3])) );
+  sprintf(valuestr, "%08X", (int)(((u32)(regs->CT[0]))<<24 | ((u32)(regs->CT[1]))<<16 | ((u32)(regs->CT[2]))<<8 | ((u32)(regs->CT[3]))) );
   gtk_list_store_set( GTK_LIST_STORE( scudsp->regListStore ), &iter, 0, "CT", 1, valuestr, -1 );
   SCUDSPUPDATEREGLISTx(RA,regs->RA0,%08X);
   SCUDSPUPDATEREGLISTx(WA,regs->WA0,%08X);
@@ -324,7 +324,7 @@ static void yui_scudsp_update_codelist( YuiScudsp *scudsp, u32 addr) {
 static void yui_scudsp_step( GtkWidget* widget, YuiScudsp * scudsp ) {
 
   ScuDspStep();
-  yui_window_invalidate( widget, yui ); /* update all dialogs, including us */
+  yui_window_invalidate( yui ); /* update all dialogs, including us */
 }
 
 static void yui_scudsp_editedReg( GtkCellRendererText *cellrenderertext,
@@ -347,7 +347,7 @@ static void yui_scudsp_editedReg( GtkCellRendererText *cellrenderertext,
     scudspsetRegister( scudsp, i, addr );
     gtk_list_store_set( GTK_LIST_STORE( scudsp->regListStore ), &iter, 1, bptext, -1 );
   }
-  yui_window_invalidate( NULL, yui );
+  yui_window_invalidate( yui );
 }
 
 static void yui_scudsp_editedBp( GtkCellRendererText *cellrenderertext,
@@ -375,7 +375,7 @@ static void yui_scudsp_editedBp( GtkCellRendererText *cellrenderertext,
   gtk_list_store_set( GTK_LIST_STORE( scudsp->bpListStore ), &iter, 0, bptext, -1 );
 }
 
-static void debugPauseLoop() { /* secondary gtk event loop for the "breakpoint pause" state */
+static void debugPauseLoop(void) { /* secondary gtk event loop for the "breakpoint pause" state */
 
   while ( !(yui->state & YUI_IS_RUNNING) )
     if ( gtk_main_iteration() ) return;
@@ -383,7 +383,7 @@ static void debugPauseLoop() { /* secondary gtk event loop for the "breakpoint p
 
 static void yui_scudsp_breakpoint_handler (u32 addr) {
 
-  yui_window_pause(NULL, yui);
+  yui_window_pause(yui);
   {
     scudspregs_struct scudspregs;
     YuiScudsp* scudsp = YUI_SCUDSP(yui_scudsp_new( yui ));
