@@ -18,6 +18,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file memory.c
+    \brief Memory access functions.
+*/
+
 #ifdef PSP  // see FIXME in T1MemoryInit()
 # include <stdint.h>
 #endif
@@ -1106,6 +1110,7 @@ int YabSaveState(const char *filename)
    fseek(fp, 16, SEEK_SET);
    ywrite(&check, (void *)&movieposition, sizeof(movieposition), 1, fp);
 
+   free(buf);
    fclose(fp);
 
    OSDPushMessage(OSDMSG_STATUS, 150, "STATE SAVED");
@@ -1334,6 +1339,7 @@ int YabLoadState(const char *filename)
    glDrawPixels(outputwidth, outputheight, GL_RGBA, GL_UNSIGNED_BYTE, buf);
    #endif
    YuiSwapBuffers();
+   free(buf);
 
    fseek(fp, movieposition, SEEK_SET);
    MovieReadState(fp, filename);
