@@ -17,6 +17,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file netlink.c
+    \brief Netlink emulation functions.
+*/
+
 
 #include <ctype.h>
 #include "cs2.h"
