@@ -17,6 +17,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file osdcore.c
+    \brief OSD dummy, glut, and software interfaces.
+*/
+
 #include "osdcore.h"
 #include "vdp1.h"
 #include "font.h"
@@ -42,7 +46,9 @@ OSD_struct *OSDCoreList[] = {
 #ifdef HAVE_LIBGLUT
 &OSDGlut,
 #endif
+#ifndef _arch_dreamcast
 &OSDSoft,
+#endif
 NULL
 };
 #else
@@ -319,6 +325,8 @@ int OSDGlutUseBuffer(void)
 }
 #endif
 
+#ifndef _arch_dreamcast
+
 static int OSDSoftInit(void);
 static void OSDSoftDeInit(void);
 static void OSDSoftReset(void);
@@ -391,3 +399,5 @@ int OSDSoftUseBuffer(void)
 {
    return 1;
 }
+
+#endif /* !_arch_dreamcast */
