@@ -27,8 +27,7 @@
 int  PERLinuxJoyInit(void);
 void PERLinuxJoyDeInit(void);
 int  PERLinuxJoyHandleEvents(void);
-void PERLinuxJoyNothing(void);
-u32  PERLinuxJoyScan(void);
+u32  PERLinuxJoyScan(u32 flags);
 void PERLinuxJoyFlush(void);
 void PERLinuxKeyName(u32 key, char * name, int size);
 
@@ -38,13 +37,10 @@ PERCORE_LINUXJOY,
 PERLinuxJoyInit,
 PERLinuxJoyDeInit,
 PERLinuxJoyHandleEvents,
-PERLinuxJoyNothing,
 PERLinuxJoyScan,
 1,
-PERLinuxJoyFlush
-#ifdef PERKEYNAME
-,PERLinuxKeyName
-#endif
+PERLinuxJoyFlush,
+PERLinuxKeyName
 };
 
 static int hJOY = -1;
@@ -71,12 +67,6 @@ void PERLinuxJoyDeInit(void)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void PERLinuxJoyNothing(void)
-{
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
 int PERLinuxJoyHandleEvents(void)
 {
    struct js_event evt;
@@ -108,7 +98,7 @@ int PERLinuxJoyHandleEvents(void)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 PERLinuxJoyScan(void) {
+u32 PERLinuxJoyScan(u32 flags) {
    struct js_event evt;
 
    if (hJOY == -1) return 0;
