@@ -1,5 +1,5 @@
 /*  src/q68/q68-internal.h: Internal declarations/definitions used by Q68
-    Copyright 2009 Andrew Church
+    Copyright 2009-2010 Andrew Church
 
     This file is part of Yabause.
 
@@ -49,17 +49,41 @@
  */
 #define Q68_JIT_OPTIMIZE_FLAGS
 
+/**
+ * Q68_JIT_LOOSE_TIMING:  When defined, allows the dynamic translator to
+ * take some leeway in checking execution timing, such that instructions
+ * may continue to be executed even after the cycle limit has been reached.
+ * This allows the translated code to execute more quickly, but will
+ * slightly alter the timing of responses to external events such as
+ * interrupts.
+ */
+#define Q68_JIT_LOOSE_TIMING
+
+/**
+ * Q68_OPTIMIZE_IDLE:  When defined, optimizes certain idle loops to
+ * improve performance in JIT mode.  Enabling this option slightly alters
+ * execution timing.
+ */
+#define Q68_OPTIMIZE_IDLE
+
+/**
+ * Q68_JIT_VERBOSE:  When defined, outputs some status messages considered
+ * useful in debugging or optimizing the JIT core.
+ */
+// #define Q68_JIT_VERBOSE
+
 /**
  * Q68_DISABLE_ADDRESS_ERROR:  When defined, disables the generation of
  * address error exceptions for unaligned word/longword accesses.  The
  * behavior for such an access will depend on how the host system handles
- * unaligned accesses, and may include the emulator itself crashing.
+ * unaligned accesses, and may include the host program itself crashing.
  */
 // #define Q68_DISABLE_ADDRESS_ERROR
 
 /**
  * Q68_TRACE:  When defined, the execution of every instruction will be
- * traced to the file "q68.log" in the current directory.
+ * traced to the file "q68.log" in the current directory.  (On Linux, the
+ * trace will be written in compressed form to "q68.log.gz".)
  */
 // #define Q68_TRACE
 
@@ -150,12 +174,23 @@ struct Q68State_ {
     /* Current interrupt request level */
     unsigned int irq;
 
+    /* Number of clock cycles executed so far */
+    uint32_t cycles;
+
     /**** Environment settings ****/
 
-    /* Memory read/write functions */
+    /* Native memory allocation functions */
+    void *(*malloc_func)(size_t size);
+    void *(*realloc_func)(void *ptr, size_t size);
+    void (*free_func)(void *ptr);
+
+    /* 68k memory read/write functions */
     Q68ReadFunc *readb_func, *readw_func;
     Q68WriteFunc *writeb_func, *writew_func;
 
+    /* Native cache flushing function (for JIT) */
+    void (*jit_flush)(void);
+
     /**** JIT-related data ****/
 
     /* Currently executing JIT block (NULL = none) */
@@ -286,17 +321,19 @@ extern Q68JitEntry *q68_jit_translate(Q68State *state, uint32_t address);
 extern Q68JitEntry *q68_jit_find(Q68State *state, uint32_t address);
 
 /**
- * q68_jit_run:  Run translated 68000 code for the given number of cycles.
+ * q68_jit_run:  Run translated 68000 code.
  *
  * [Parameters]
  *           state: Processor state block
- *          cycles: Number of clock cycles to execute
+ *     cycle_limit: Clock cycle limit on execution (code will stop when
+ *                     state->cycles >= cycles)
  *     address_ptr: Pointer to translated block to execute; will be cleared
  *                     to NULL on return if the end of the block was reached
  * [Return value]
- *     Number of clock cycles actually executed
+ *     None
  */
-extern int q68_jit_run(Q68State *state, int cycles, Q68JitEntry **entry_ptr);
+extern void q68_jit_run(Q68State *state, uint32_t cycle_limit,
+                        Q68JitEntry **entry_ptr);
 
 /**
  * q68_jit_clear:  Clear any translation beginning at the given address.
