@@ -17,6 +17,7 @@
 	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 #include "UICheatRaw.h"
+#include "UIHexInput.h"
 #include "../QtYabause.h"
 
 #include <QButtonGroup>
@@ -33,7 +34,10 @@ UICheatRaw::UICheatRaw( QWidget* p )
 	mButtonGroup->addButton( rbByte, CHEATTYPE_BYTEWRITE );
 	mButtonGroup->addButton( rbWord, CHEATTYPE_WORDWRITE );
 	mButtonGroup->addButton( rbLong, CHEATTYPE_LONGWRITE );
-	
+
+	leAddress->setValidator(new HexValidator(0x00000000, 0xFFFFFFFF, leAddress));
+	leValue->setValidator(new HexValidator(0x00000000, 0xFFFFFFFF, leValue));
+
 	// retranslate widgets
 	QtYabause::retranslateWidget( this );
 }
