@@ -110,6 +110,10 @@ UIYabause::UIYabause( QWidget* parent )
 	mLogDock->setVisible( false );
 	// create emulator thread
 	mYabauseThread = new YabauseThread( this );
+	// create hide mouse timer
+	hideMouseTimer = new QTimer();
+	// create mouse cursor timer
+	mouseCursorTimer = new QTimer();
 	// connectionsdd
 	connect( mYabauseThread, SIGNAL( requestSize( const QSize& ) ), this, SLOT( sizeRequested( const QSize& ) ) );
 	connect( mYabauseThread, SIGNAL( requestFullscreen( bool ) ), this, SLOT( fullscreenRequested( bool ) ) );
@@ -119,6 +123,9 @@ UIYabause::UIYabause( QWidget* parent )
 	connect( mYabauseThread, SIGNAL( error( const QString&, bool ) ), this, SLOT( errorReceived( const QString&, bool ) ) );
 	connect( mYabauseThread, SIGNAL( pause( bool ) ), this, SLOT( pause( bool ) ) );
 	connect( mYabauseThread, SIGNAL( reset() ), this, SLOT( reset() ) );
+	connect( hideMouseTimer, SIGNAL( timeout() ), this, SLOT( hideMouse() ));
+	connect( mouseCursorTimer, SIGNAL( timeout() ), this, SLOT( cursorRestore() ));
+	connect( mYabauseThread, SIGNAL( toggleEmulateMouse( bool ) ), this, SLOT( toggleEmulateMouse( bool ) ) );
 
 	// Load shortcuts
 	VolatileSettings* vs = QtYabause::volatileSettings();
@@ -145,6 +152,9 @@ UIYabause::UIYabause( QWidget* parent )
 	restoreGeometry( vs->value("General/Geometry" ).toByteArray() );
 	mYabauseGL->setMouseTracking(true);
 	setMouseTracking(true);
+	mouseXRatio = mouseYRatio = 1.0;
+	emulateMouse = false;
+	mouseSensitivity = vs->value( "Input/GunMouseSensitivity", 100 ).toInt();
 	showMenuBarHeight = menubar->height();
 	translations = QtYabause::getTranslationList();
 }
@@ -202,18 +212,73 @@ void UIYabause::mouseReleaseEvent( QMouseEvent* e )
 	PerKeyUp( (1 << 31) | e->button() );
 }
 
+void UIYabause::hideMouse()
+{
+	this->setCursor(Qt::BlankCursor);
+	hideMouseTimer->stop();
+}
+
+void UIYabause::cursorRestore()
+{
+	this->setCursor(Qt::ArrowCursor);
+	mouseCursorTimer->stop();
+}
+
 void UIYabause::mouseMoveEvent( QMouseEvent* e )
 { 
-	PerAxisMove((1 << 30), e->x()-oldMouseX, oldMouseY-e->y());
-	oldMouseX = e->x();
-	oldMouseY = e->y();
+	int x = (e->x()-oldMouseX)*mouseXRatio;
+	int y = (oldMouseY-e->y())*mouseYRatio;
+	int minAdj = mouseSensitivity/100;
+
+	// If minimum movement is less than x, wait until next pass to apply	
+	if (abs(x) < minAdj) x = 0;
+	if (abs(y) < minAdj) y = 0;
+
+	PerAxisMove((1 << 30), x, y);
+
+	oldMouseX = oldMouseX+(x/mouseXRatio);
+	oldMouseY = oldMouseY-(y/mouseYRatio);	
+
 	VolatileSettings* vs = QtYabause::volatileSettings();
-	if (isFullScreen() && vs->value( "View/Menubar" ).toInt() == BD_SHOWONFSHOVER )
+
+	if (!isFullScreen())
 	{
-		if (e->y() < showMenuBarHeight)
-			menubar->show();
+		if (emulateMouse)
+		{
+			int menuToolHeight = menubar->height() + toolBar->height();
+			if (oldMouseY > menuToolHeight)
+				this->setCursor(Qt::BlankCursor);
+			else
+				this->setCursor(Qt::ArrowCursor);
+			return;
+		}
 		else
-			menubar->hide();
+			this->setCursor(Qt::ArrowCursor);
+	}
+	else
+	{
+		if (vs->value( "View/Menubar" ).toInt() == BD_SHOWONFSHOVER)
+		{
+			if (e->y() < showMenuBarHeight)
+				menubar->show();
+			else
+			{
+				menubar->hide();
+				if (emulateMouse)
+				{
+					this->setCursor(Qt::BlankCursor);
+					return;
+				}
+			}
+		}
+		else if (emulateMouse)
+		{
+			this->setCursor(Qt::BlankCursor);
+			return;
+		}
+
+		hideMouseTimer->start(3 * 1000);
+		this->setCursor(Qt::ArrowCursor);
 	}
 }
 
@@ -265,6 +330,10 @@ void UIYabause::sizeRequested( const QSize& s )
 		width=s.width();
 		height=s.height();
 	}
+
+	mouseXRatio = 320.0 / (float)width * 2.0 * (float)mouseSensitivity / 100.0;
+	mouseYRatio = 240.0 / (float)height * 2.0 * (float)mouseSensitivity / 100.0;
+
 	// Compensate for menubar and toolbar
 	VolatileSettings* vs = QtYabause::volatileSettings();
 	if (vs->value( "View/Menubar" ).toInt() != BD_ALWAYSHIDE)
@@ -397,6 +466,9 @@ void UIYabause::fullscreenRequested( bool f )
 			menubar->show();
 		if ( vs->value( "View/Toolbar" ).toInt() == BD_HIDEFS )
 			toolBar->show();
+
+		setCursor(Qt::ArrowCursor);
+		hideMouseTimer->stop();
 	}
 	else if ( !isFullScreen() && f )
 	{
@@ -413,6 +485,8 @@ void UIYabause::fullscreenRequested( bool f )
 			menubar->hide();
 		if ( vs->value( "View/Toolbar" ).toInt() == BD_HIDEFS )
 			toolBar->hide();
+
+		hideMouseTimer->start(3 * 1000);
 	}
 	if ( aViewFullscreen->isChecked() != f )
 		aViewFullscreen->setChecked( f );
@@ -488,6 +562,7 @@ void UIYabause::on_aFileSettings_triggered()
 		VolatileSettings* vs = QtYabause::volatileSettings();
 		aEmulationFrameSkipLimiter->setChecked( vs->value( "General/EnableFrameSkipLimiter" ).toBool() );
 		aViewFPS->setChecked( vs->value( "General/ShowFPS" ).toBool() );
+		mouseSensitivity = vs->value( "Input/GunMouseSensitivity" ).toInt();
 		
 		if(isFullScreen())
 		{
@@ -558,7 +633,8 @@ void UIYabause::on_aFileSettings_triggered()
 			ScspChangeSoundCore(newhash["Sound/SoundCore"].toInt());
 		
 		if (newhash["Video/WindowWidth"] != hash["Video/WindowWidth"] || newhash["Video/WindowHeight"] != hash["Video/WindowHeight"] ||
-          newhash["View/Menubar"] != hash["View/Menubar"] || newhash["View/Toolbar"] != hash["View/Toolbar"])
+          newhash["View/Menubar"] != hash["View/Menubar"] || newhash["View/Toolbar"] != hash["View/Toolbar"] || 
+			 newhash["Input/GunMouseSensitivity"] != hash["Input/GunMouseSensitivity"])
 			sizeRequested(QSize(newhash["Video/WindowWidth"].toInt(),newhash["Video/WindowHeight"].toInt()));
 		
 		if (newhash["Video/FullscreenWidth"] != hash["Video/FullscreenWidth"] || 
@@ -702,10 +778,12 @@ void UIYabause::on_aFileQuit_triggered()
 void UIYabause::on_aEmulationRun_triggered()
 {
 	if ( mYabauseThread->emulationPaused() )
-   {
+	{
 		mYabauseThread->pauseEmulation( false, false );
-      refreshStatesActions();
-   }
+		refreshStatesActions();
+		if (isFullScreen())
+			hideMouseTimer->start(3 * 1000);
+	}
 }
 
 void UIYabause::on_aEmulationPause_triggered()
@@ -883,7 +961,8 @@ void UIYabause::on_aHelpAbout_triggered()
 
 void UIYabause::on_aSound_triggered()
 {
-	// show volume widget
+	// show volume widget	
+	sVolume->setValue(QtYabause::volatileSettings()->value( "Sound/Volume").toInt());
 	QWidget* ab = toolBar->widgetForAction( aSound );
 	fSound->move( ab->mapToGlobal( ab->rect().bottomLeft() ) );
 	fSound->show();
@@ -950,3 +1029,9 @@ void UIYabause::reset()
 {
 	mYabauseGL->updateView();
 }
+
+void UIYabause::toggleEmulateMouse( bool enable )
+{
+	emulateMouse = enable;
+}
+
