@@ -18,6 +18,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file scu.c
+    \brief SCU emulation functions.
+*/
+
 #include <stdlib.h>
 #include "scu.h"
 #include "debug.h"
@@ -2324,10 +2328,9 @@ void ScuSendVBlankIN(void) {
 
 void ScuSendVBlankOUT(void) {
    SendInterrupt(0x41, 0xE, 0x0002, 0x0002);
+	ScuRegs->timer0 = 0;
    if (ScuRegs->T1MD & 0x1)
    {
-      ScuRegs->timer0 = 0;
-
       if (ScuRegs->timer0 == ScuRegs->T0C)
          ScuSendTimer0();
    }
@@ -2338,10 +2341,9 @@ void ScuSendVBlankOUT(void) {
 void ScuSendHBlankIN(void) {
    SendInterrupt(0x42, 0xD, 0x0004, 0x0004);
 
+	ScuRegs->timer0++;
    if (ScuRegs->T1MD & 0x1)
    {
-      ScuRegs->timer0++;
-
       // if timer0 equals timer 0 compare register, do an interrupt
       if (ScuRegs->timer0 == ScuRegs->T0C)
          ScuSendTimer0();
