@@ -17,6 +17,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file sndsdl.c
+    \brief SDL sound interface.
+*/
+
 #ifdef HAVE_LIBSDL
 
 #include <stdlib.h>
