@@ -19,6 +19,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+/*! \file ygl.c
+    \brief OpenGL rendering functions
+*/
+
 #ifdef HAVE_LIBGL
 #include <stdlib.h>
 #include <math.h>
